==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
            a.item("StrokeThickness", "Number:double");
            a.item("StrokeDashArray", "DoubleCollection:double");
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ac("AssigningSeriesShapeStyleEventArgsBase", AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
            a.item("StrokeThickness", "Number:double");
            a.item("StrokeDashArray", "DoubleCollection:double");
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ad("AssigningSeriesShapeStyleEventArgsBase", AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata, 'AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata');
    AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata;
})();
